Diff
Modified: trunk/Source/WebCore/ChangeLog (222697 => 222698)
--- trunk/Source/WebCore/ChangeLog 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/ChangeLog 2017-10-02 06:02:52 UTC (rev 222698)
@@ -1,3 +1,68 @@
+2017-10-01 Sam Weinig <[email protected]>
+
+ [Settings] Move remaining simple settings to Settings.in
+ https://bugs.webkit.org/show_bug.cgi?id=177730
+
+ Reviewed by Darin Adler.
+
+ - Adds new option type for Settings.in, 'getter', which allows you to specify
+ a custom name for the setting's getter. For instance, the setting javaEnabled
+ has a custom getter name, 'isJavaEnabled'.
+ - Adds support for WTF::Seconds as a type of setting. Used by only
+ timeWithoutMouseMovementBeforeHidingControls at the moment.
+ - Moves non-generated settings from Settings.h/cpp that don't require custom
+ action when set, to Settings.in
+
+ * Scripts/GenerateSettings/GenerateInternalSettingsImplementationFile.py:
+ * Scripts/GenerateSettings/GenerateSettingsHeaderFile.py:
+ * Scripts/GenerateSettings/Settings.py:
+
+ Add support for 'getter' and the Seconds type.
+
+ * WebCore.xcodeproj/project.pbxproj:
+ * platform/text/FontRenderingMode.h: Copied from Source/WebCore/platform/text/TextFlags.h.
+ * platform/text/TextFlags.h:
+
+ Add FontRenderingMode.h. Moved out of TextFlags.h to be accessible by
+ the settings generator.
+
+ * page/Settings.cpp:
+ (WebCore::Settings::Settings):
+ (WebCore::Settings::setJavaEnabled): Deleted.
+ (WebCore::Settings::setJavaEnabledForLocalFiles): Deleted.
+ (WebCore::Settings::setPreferMIMETypeForImages): Deleted.
+ (WebCore::Settings::setForcePendingWebGLPolicy): Deleted.
+ (WebCore::Settings::setNeedsAdobeFrameReloadingQuirk): Deleted.
+ (WebCore::Settings::setFontRenderingMode): Deleted.
+ (WebCore::Settings::fontRenderingMode const): Deleted.
+ (WebCore::Settings::setShowTiledScrollingIndicator): Deleted.
+ (WebCore::Settings::setFontFallbackPrefersPictographs): Deleted.
+ (WebCore::Settings::setWebFontsAlwaysFallBack): Deleted.
+ * page/Settings.h:
+ (WebCore::Settings::isJavaEnabled const): Deleted.
+ (WebCore::Settings::isJavaEnabledForLocalFiles const): Deleted.
+ (WebCore::Settings::preferMIMETypeForImages const): Deleted.
+ (WebCore::Settings::needsAcrobatFrameReloadingQuirk const): Deleted.
+ (WebCore::Settings::showTiledScrollingIndicator const): Deleted.
+ (WebCore::Settings::setTouchEventEmulationEnabled): Deleted.
+ (WebCore::Settings::isTouchEventEmulationEnabled const): Deleted.
+ (WebCore::Settings::setTimeWithoutMouseMovementBeforeHidingControls): Deleted.
+ (WebCore::Settings::timeWithoutMouseMovementBeforeHidingControls const): Deleted.
+ (WebCore::Settings::fontFallbackPrefersPictographs const): Deleted.
+ (WebCore::Settings::webFontsAlwaysFallBack const): Deleted.
+ (WebCore::Settings::setMediaKeysStorageDirectory): Deleted.
+ (WebCore::Settings::mediaKeysStorageDirectory const): Deleted.
+ (WebCore::Settings::setMediaDeviceIdentifierStorageDirectory): Deleted.
+ (WebCore::Settings::mediaDeviceIdentifierStorageDirectory const): Deleted.
+ (WebCore::Settings::applePayEnabled const): Deleted.
+ (WebCore::Settings::setApplePayEnabled): Deleted.
+ (WebCore::Settings::applePayCapabilityDisclosureAllowed const): Deleted.
+ (WebCore::Settings::setApplePayCapabilityDisclosureAllowed): Deleted.
+ (WebCore::Settings::isForcePendingWebGLPolicy const): Deleted.
+ * page/Settings.in:
+
+ Moved hand-written settings to be Settings.in based.
+
2017-10-01 Zalan Bujtas <[email protected]>
RenderView does not need to be a SelectionSubtreeRoot
Modified: trunk/Source/WebCore/Scripts/GenerateSettings/GenerateInternalSettingsImplementationFile.py (222697 => 222698)
--- trunk/Source/WebCore/Scripts/GenerateSettings/GenerateInternalSettingsImplementationFile.py 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/Scripts/GenerateSettings/GenerateInternalSettingsImplementationFile.py 2017-10-02 06:02:52 UTC (rev 222698)
@@ -25,7 +25,7 @@
import os.path
-from Settings import license, makeSetterFunctionName, makeConditionalString, mapToIDLType, makeConditionalString
+from Settings import license, makeSetterFunctionName, makeGetterFunctionName, makeConditionalString, mapToIDLType
def generateInternalSettingsImplementationFile(outputDirectory, settings):
@@ -53,7 +53,7 @@
if setting.conditional:
outputFile.write("#if " + makeConditionalString(setting.conditional) + "\n")
- outputFile.write(" , m_" + setting.name + "(page->settings()." + setting.name + "())\n")
+ outputFile.write(" , m_" + setting.name + "(page->settings()." + makeGetterFunctionName(setting) + "())\n")
if setting.conditional:
outputFile.write("#endif\n")
Modified: trunk/Source/WebCore/Scripts/GenerateSettings/GenerateSettingsHeaderFile.py (222697 => 222698)
--- trunk/Source/WebCore/Scripts/GenerateSettings/GenerateSettingsHeaderFile.py 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/Scripts/GenerateSettings/GenerateSettingsHeaderFile.py 2017-10-02 06:02:52 UTC (rev 222698)
@@ -25,7 +25,7 @@
import os.path
-from Settings import license, makeConditionalString, makeSetterFunctionName, includeForSetting, typeIsAggregate
+from Settings import license, makeConditionalString, makeSetterFunctionName, makeGetterFunctionName, includeForSetting, typeIsValueType
def generateSettingsHeaderFile(outputDirectory, settings):
@@ -112,21 +112,22 @@
def printGetterAndSetter(outputFile, setting):
setterFunctionName = makeSetterFunctionName(setting)
+ getterFunctionName = makeGetterFunctionName(setting)
# Export is only needed if the definition is not in the header.
webcoreExport = "WEBCORE_EXPORT " if setting.setNeedsStyleRecalcInAllFrames else ""
- if not typeIsAggregate(setting):
- outputFile.write(" " + setting.type + " " + setting.name + "() const { return m_" + setting.name + "; } \n")
+ if not typeIsValueType(setting):
+ outputFile.write(" " + setting.type + " " + getterFunctionName + "() const { return m_" + setting.name + "; } \n")
outputFile.write(" " + webcoreExport + "void " + setterFunctionName + "(" + setting.type + " " + setting.name + ")")
else:
- outputFile.write(" const " + setting.type + "& " + setting.name + "() const { return m_" + setting.name + "; } \n")
+ outputFile.write(" const " + setting.type + "& " + getterFunctionName + "() const { return m_" + setting.name + "; } \n")
outputFile.write(" " + webcoreExport + "void " + setterFunctionName + "(const " + setting.type + "& " + setting.name + ")")
if setting.setNeedsStyleRecalcInAllFrames:
- outputFile.write("; \n")
+ outputFile.write(";\n\n")
else:
- outputFile.write(" { m_" + setting.name + " = " + setting.name + "; } \n")
+ outputFile.write(" { m_" + setting.name + " = " + setting.name + "; }\n\n")
def printGettersAndSetters(outputFile, sortedUnconditionalSettingsNames, sortedConditionals, settingsByConditional, settings):
Modified: trunk/Source/WebCore/Scripts/GenerateSettings/GenerateSettingsImplementationFile.py (222697 => 222698)
--- trunk/Source/WebCore/Scripts/GenerateSettings/GenerateSettingsImplementationFile.py 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/Scripts/GenerateSettings/GenerateSettingsImplementationFile.py 2017-10-02 06:02:52 UTC (rev 222698)
@@ -25,7 +25,7 @@
import os.path
-from Settings import license, makeConditionalString, makeSetterFunctionName, typeIsAggregate
+from Settings import license, makeConditionalString, makeSetterFunctionName, typeIsValueType
def generateSettingsImplementationFile(outputDirectory, settings):
@@ -155,7 +155,7 @@
setterFunctionName = makeSetterFunctionName(setting)
- if not typeIsAggregate(setting):
+ if not typeIsValueType(setting):
outputFile.write("void SettingsGenerated::" + setterFunctionName + "(" + setting.type + " " + setting.name + ")\n")
else:
outputFile.write("void SettingsGenerated::" + setterFunctionName + "(const " + setting.type + "& " + setting.name + ")\n")
Modified: trunk/Source/WebCore/Scripts/GenerateSettings/Settings.py (222697 => 222698)
--- trunk/Source/WebCore/WebCore.xcodeproj/project.pbxproj 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/WebCore.xcodeproj/project.pbxproj 2017-10-02 06:02:52 UTC (rev 222698)
@@ -3197,6 +3197,7 @@
7C1F5D591F22FF7300A8874F /* JSDOMConvertScheduledAction.h in Headers */ = {isa = PBXBuildFile; fileRef = 7C1F5D581F22FF7300A8874F /* JSDOMConvertScheduledAction.h */; };
7C2BDD3D17C7F98C0038FF15 /* JSDOMGlobalObjectTask.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 7C2BDD3B17C7F98B0038FF15 /* JSDOMGlobalObjectTask.cpp */; };
7C2BDD3E17C7F98C0038FF15 /* JSDOMGlobalObjectTask.h in Headers */ = {isa = PBXBuildFile; fileRef = 7C2BDD3C17C7F98B0038FF15 /* JSDOMGlobalObjectTask.h */; };
+ 7C2F8BC21F81BF5B00305C32 /* FontRenderingMode.h in Headers */ = {isa = PBXBuildFile; fileRef = 7CCB11D81F81B22000849AFD /* FontRenderingMode.h */; settings = {ATTRIBUTES = (Private, ); }; };
7C2FA6111EA95A3900A03108 /* ResourceCryptographicDigest.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 7C2FA60F1EA95A3200A03108 /* ResourceCryptographicDigest.cpp */; };
7C2FA6121EA95A3C00A03108 /* ResourceCryptographicDigest.h in Headers */ = {isa = PBXBuildFile; fileRef = 7C2FA6101EA95A3200A03108 /* ResourceCryptographicDigest.h */; settings = {ATTRIBUTES = (Private, ); }; };
7C30D9831F815AEC00268356 /* JSAbortController.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 7C30D97E1F815AC000268356 /* JSAbortController.cpp */; };
@@ -11640,6 +11641,7 @@
7CC6993E191EC5F500AF2270 /* JSWebKitNamespace.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = JSWebKitNamespace.cpp; sourceTree = "<group>"; };
7CC6993F191EC5F500AF2270 /* JSWebKitNamespace.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = JSWebKitNamespace.h; sourceTree = "<group>"; };
7CC7E3D617208C0F003C5277 /* IDNScriptWhiteList.txt */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text; path = IDNScriptWhiteList.txt; sourceTree = "<group>"; };
+ 7CCB11D81F81B22000849AFD /* FontRenderingMode.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = FontRenderingMode.h; sourceTree = "<group>"; };
7CD0BA021B8F79C9005CEBBE /* ActiveDOMCallbackMicrotask.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = ActiveDOMCallbackMicrotask.cpp; sourceTree = "<group>"; };
7CD0BA031B8F79C9005CEBBE /* ActiveDOMCallbackMicrotask.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = ActiveDOMCallbackMicrotask.h; sourceTree = "<group>"; };
7CD0E2B51F80A4820016A4CE /* AbortController.h */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.c.h; path = AbortController.h; sourceTree = "<group>"; };
@@ -23978,6 +23980,7 @@
0FDA7C2018832BCC00C954B5 /* DateTimeFormat.cpp */,
453EB635159C570400001BB7 /* DateTimeFormat.h */,
CECCFC3A141973D5002A0AC1 /* DecodeEscapeSequences.h */,
+ 7CCB11D81F81B22000849AFD /* FontRenderingMode.h */,
375CD231119D43C800A2A859 /* Hyphenation.h */,
89B5EA9F11E8003D00F2367E /* LineEnding.cpp */,
89B5EAA011E8003D00F2367E /* LineEnding.h */,
@@ -26166,6 +26169,12 @@
children = (
CE2616A4187E65C1007955F3 /* ios */,
2D5036661BCDDDC400E20BB3 /* mac */,
+ 7CD0E2B61F80A4820016A4CE /* AbortController.cpp */,
+ 7CD0E2B51F80A4820016A4CE /* AbortController.h */,
+ 7CD0E2B71F80A4820016A4CE /* AbortController.idl */,
+ 7CD0E2BD1F80A56E0016A4CE /* AbortSignal.cpp */,
+ 7CD0E2BC1F80A56E0016A4CE /* AbortSignal.h */,
+ 7CD0E2BE1F80A56E0016A4CE /* AbortSignal.idl */,
7C5222971E1DAE16002CB8F7 /* ActiveDOMCallback.cpp */,
7C5222981E1DAE16002CB8F7 /* ActiveDOMCallback.h */,
7CD0BA021B8F79C9005CEBBE /* ActiveDOMCallbackMicrotask.cpp */,
@@ -26173,12 +26182,6 @@
E1C4DE6D0EA75C650023CCD6 /* ActiveDOMObject.cpp */,
E1C4DE680EA75C1E0023CCD6 /* ActiveDOMObject.h */,
83BB5C871D5D6F3A005A71F4 /* AllDescendantsCollection.h */,
- 7CD0E2B51F80A4820016A4CE /* AbortController.h */,
- 7CD0E2B61F80A4820016A4CE /* AbortController.cpp */,
- 7CD0E2B71F80A4820016A4CE /* AbortController.idl */,
- 7CD0E2BC1F80A56E0016A4CE /* AbortSignal.h */,
- 7CD0E2BD1F80A56E0016A4CE /* AbortSignal.cpp */,
- 7CD0E2BE1F80A56E0016A4CE /* AbortSignal.idl */,
319847FE1A1D816700A13318 /* AnimationEvent.cpp */,
319847FF1A1D816700A13318 /* AnimationEvent.h */,
319848001A1D816700A13318 /* AnimationEvent.idl */,
@@ -27073,6 +27076,8 @@
isa = PBXHeadersBuildPhase;
buildActionMask = 2147483647;
files = (
+ 7CD0E2B81F80A4820016A4CE /* AbortController.h in Headers */,
+ 7CD0E2BF1F80A56E0016A4CE /* AbortSignal.h in Headers */,
F48223131E386E240066FC79 /* AbstractPasteboard.h in Headers */,
41E1B1D10FF5986900576B3B /* AbstractWorker.h in Headers */,
29A8122E0FBB9C1D00510293 /* AccessibilityARIAGridCell.h in Headers */,
@@ -27959,6 +27964,7 @@
0845680812B90DA600960A9F /* FontMetrics.h in Headers */,
B5320D6B122A24E9002D1440 /* FontPlatformData.h in Headers */,
371F4FFC0D25E7F300ECE0D5 /* FontRanges.h in Headers */,
+ 7C2F8BC21F81BF5B00305C32 /* FontRenderingMode.h in Headers */,
C2AB0AF71E6B3C6C001348C5 /* FontSelectionAlgorithm.h in Headers */,
B2C3DA6B0D006CD600EF6F26 /* FontSelector.h in Headers */,
E419041F1CC6486B00C35F5D /* FontSelectorClient.h in Headers */,
@@ -28374,6 +28380,8 @@
2D0B4AAB18DA1CCD00434DE1 /* IOSurface.h in Headers */,
1C21E57D183ED1FF001C289D /* IOSurfacePool.h in Headers */,
07AC47021952102100EE9723 /* ISOVTTCue.h in Headers */,
+ 7C30D9841F815AEC00268356 /* JSAbortController.h in Headers */,
+ 7C30D9861F815AEC00268356 /* JSAbortSignal.h in Headers */,
418F88050FF957AF0080F045 /* JSAbstractWorker.h in Headers */,
5704405A1E53936200356601 /* JSAesCbcCfbParams.h in Headers */,
57E1E5AD1E8DD09B00EE37C9 /* JSAesCtrParams.h in Headers */,
@@ -29387,7 +29395,6 @@
52F10866162B6DA8009AC81E /* MixedContentChecker.h in Headers */,
CDF2B0111820540600F2B424 /* MockBox.h in Headers */,
CDF4B7241E03BF8100E235A2 /* MockCDMFactory.h in Headers */,
- 7C30D9841F815AEC00268356 /* JSAbortController.h in Headers */,
CDF4B7201E03BF6F00E235A2 /* MockCDMFactory.idl in Headers */,
51058AE01D67C229009A538C /* MockGamepad.h in Headers */,
51058AE21D67C229009A538C /* MockGamepadProvider.h in Headers */,
@@ -30281,7 +30288,6 @@
B22279950D00BF220071B782 /* SVGAnimateTransformElement.h in Headers */,
B22279980D00BF220071B782 /* SVGAnimationElement.h in Headers */,
439D334513A6911C00C20F4F /* SVGAnimatorFactory.h in Headers */,
- 7C30D9861F815AEC00268356 /* JSAbortSignal.h in Headers */,
08FB3F8413BC754C0099FC18 /* SVGAttributeToPropertyMap.h in Headers */,
B222799C0D00BF220071B782 /* SVGCircleElement.h in Headers */,
B222799F0D00BF220071B782 /* SVGClipPathElement.h in Headers */,
@@ -30325,7 +30331,6 @@
B2227A060D00BF220071B782 /* SVGFETileElement.h in Headers */,
B2227A090D00BF220071B782 /* SVGFETurbulenceElement.h in Headers */,
845E72FC0FD2623900A87D79 /* SVGFilter.h in Headers */,
- 7CD0E2BF1F80A56E0016A4CE /* AbortSignal.h in Headers */,
081EBF3B0FD34F4100DA7559 /* SVGFilterBuilder.h in Headers */,
B2227A0C0D00BF220071B782 /* SVGFilterElement.h in Headers */,
B2227A0F0D00BF220071B782 /* SVGFilterPrimitiveStandardAttributes.h in Headers */,
@@ -30783,7 +30788,6 @@
77A17A7812F28642004E02F6 /* WebGLVertexArrayObjectOES.h in Headers */,
316BDB8C1E6E153000DE0D5A /* WebGPULayer.h in Headers */,
A5E2123C1E4924A400CE1044 /* WebHeapAgent.h in Headers */,
- 7CD0E2B81F80A4820016A4CE /* AbortController.h in Headers */,
A5840E25187B8AC200843B10 /* WebInjectedScriptHost.h in Headers */,
A584FE301864CB8400843B10 /* WebInjectedScriptManager.h in Headers */,
F48223111E3869B80066FC79 /* WebItemProviderPasteboard.h in Headers */,
@@ -31273,6 +31277,8 @@
isa = PBXSourcesBuildPhase;
buildActionMask = 2147483647;
files = (
+ 7CD0E2B91F80A4820016A4CE /* AbortController.cpp in Sources */,
+ 7CD0E2C01F80A56E0016A4CE /* AbortSignal.cpp in Sources */,
41E1B1D00FF5986900576B3B /* AbstractWorker.cpp in Sources */,
37F57AB91A50726900876F98 /* AccessibilityARIAGrid.cpp in Sources */,
37F57ABA1A50726F00876F98 /* AccessibilityARIAGridCell.cpp in Sources */,
@@ -31550,7 +31556,6 @@
CE2849891CA3614600B4A57F /* ContentSecurityPolicyDirectiveNames.cpp in Sources */,
CE799FA71C6A50570097B518 /* ContentSecurityPolicyMediaListDirective.cpp in Sources */,
CE6DADF91C591E6A003F6A88 /* ContentSecurityPolicyResponseHeaders.cpp in Sources */,
- 7C30D9851F815AEC00268356 /* JSAbortSignal.cpp in Sources */,
CE799F9F1C6A4C160097B518 /* ContentSecurityPolicySource.cpp in Sources */,
CE799F971C6A46BC0097B518 /* ContentSecurityPolicySourceList.cpp in Sources */,
CE799FAB1C6A50660097B518 /* ContentSecurityPolicySourceListDirective.cpp in Sources */,
@@ -31622,7 +31627,6 @@
E1233F10185A4130008DFAF5 /* CryptoAlgorithmRSAES_PKCS1_v1_5Mac.cpp in Sources */,
E1BD3319182D8DDD00C05D9F /* CryptoAlgorithmRSASSA_PKCS1_v1_5.cpp in Sources */,
E1C266D818317AB4003F8B33 /* CryptoAlgorithmRSASSA_PKCS1_v1_5Mac.cpp in Sources */,
- 7C30D9831F815AEC00268356 /* JSAbortController.cpp in Sources */,
E125F82B1822CFEC00D84CD9 /* CryptoAlgorithmSHA1.cpp in Sources */,
E19AC3EE1824DC7900349426 /* CryptoAlgorithmSHA224.cpp in Sources */,
E19AC3F01824DC7900349426 /* CryptoAlgorithmSHA256.cpp in Sources */,
@@ -32403,6 +32407,8 @@
1C21E57C183ED1FF001C289D /* IOSurfacePool.cpp in Sources */,
AD9FF6E11908391D003B61E0 /* IOSurfacePoolCocoa.mm in Sources */,
07AC47011952102100EE9723 /* ISOVTTCue.cpp in Sources */,
+ 7C30D9831F815AEC00268356 /* JSAbortController.cpp in Sources */,
+ 7C30D9851F815AEC00268356 /* JSAbortSignal.cpp in Sources */,
418F88040FF957AE0080F045 /* JSAbstractWorker.cpp in Sources */,
5704405C1E53937900356601 /* JSAesCbcCfbParams.cpp in Sources */,
57E1E5AC1E8DD09B00EE37C9 /* JSAesCtrParams.cpp in Sources */,
@@ -32481,7 +32487,6 @@
A584FE3B1864E2D800843B10 /* JSCommandLineAPIHost.cpp in Sources */,
93F9B6E00BA0FB7200854064 /* JSComment.cpp in Sources */,
79AC9218109945C80021266E /* JSCompositionEvent.cpp in Sources */,
- 7CD0E2C01F80A56E0016A4CE /* AbortSignal.cpp in Sources */,
FDA15EBD12B03F0B003A583A /* JSConvolverNode.cpp in Sources */,
FE6FD48D0F676E9300092873 /* JSCoordinates.cpp in Sources */,
14DCF3B21B6BE2080062D4C2 /* JSCountQueuingStrategy.cpp in Sources */,
@@ -32574,7 +32579,6 @@
836ACED21ECAAB19004BD012 /* JSDOMMatrix.cpp in Sources */,
7CBBBCCB1F56180D005EFAAC /* JSDOMMatrix2DInit.cpp in Sources */,
835657C71ECAB10700CDE72D /* JSDOMMatrixInit.cpp in Sources */,
- 7CD0E2B91F80A4820016A4CE /* AbortController.cpp in Sources */,
836ACED51ECAAB19004BD012 /* JSDOMMatrixReadOnly.cpp in Sources */,
A9D248060D757E7D00FDF959 /* JSDOMMimeType.cpp in Sources */,
A9D248080D757E7D00FDF959 /* JSDOMMimeTypeArray.cpp in Sources */,
Modified: trunk/Source/WebCore/page/Settings.cpp (222697 => 222698)
--- trunk/Source/WebCore/page/Settings.cpp 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/page/Settings.cpp 2017-10-02 06:02:52 UTC (rev 222698)
@@ -43,7 +43,6 @@
#include "Page.h"
#include "PageCache.h"
#include "RuntimeApplicationChecks.h"
-#include "StorageMap.h"
#include <limits>
#include <wtf/NeverDestroyed.h>
#include <wtf/StdLibExtras.h>
@@ -148,30 +147,17 @@
, m_storageBlockingPolicy(SecurityOrigin::AllowAllStorage)
, m_layoutInterval(layoutScheduleThreshold)
, m_minimumDOMTimerInterval(DOMTimer::defaultMinimumInterval())
- , m_isJavaEnabled(false)
- , m_isJavaEnabledForLocalFiles(true)
, m_loadsImagesAutomatically(false)
, m_areImagesEnabled(true)
- , m_preferMIMETypeForImages(false)
, m_arePluginsEnabled(false)
, m_isScriptEnabled(false)
- , m_needsAdobeFrameReloadingQuirk(false)
, m_usesPageCache(false)
- , m_fontRenderingMode(0)
- , m_showTiledScrollingIndicator(false)
, m_backgroundShouldExtendBeyondPage(false)
, m_dnsPrefetchingEnabled(false)
-#if ENABLE(TOUCH_EVENTS)
- , m_touchEventEmulationEnabled(false)
-#endif
, m_scrollingPerformanceLoggingEnabled(false)
- , m_timeWithoutMouseMovementBeforeHidingControls(3_s)
, m_setImageLoadingSettingsTimer(*this, &Settings::imageLoadingSettingsTimerFired)
, m_hiddenPageDOMTimerThrottlingEnabled(false)
, m_hiddenPageCSSAnimationSuspensionEnabled(false)
- , m_fontFallbackPrefersPictographs(false)
- , m_webFontsAlwaysFallBack(false)
- , m_forcePendingWebGLPolicy(false)
{
// A Frame may not have been created yet, so we initialize the AtomicString
// hash before trying to use it.
@@ -344,16 +330,6 @@
#endif
}
-void Settings::setJavaEnabled(bool isJavaEnabled)
-{
- m_isJavaEnabled = isJavaEnabled;
-}
-
-void Settings::setJavaEnabledForLocalFiles(bool isJavaEnabledForLocalFiles)
-{
- m_isJavaEnabledForLocalFiles = isJavaEnabledForLocalFiles;
-}
-
void Settings::setImagesEnabled(bool areImagesEnabled)
{
m_areImagesEnabled = areImagesEnabled;
@@ -362,16 +338,6 @@
m_setImageLoadingSettingsTimer.startOneShot(0_s);
}
-void Settings::setPreferMIMETypeForImages(bool preferMIMETypeForImages)
-{
- m_preferMIMETypeForImages = preferMIMETypeForImages;
-}
-
-void Settings::setForcePendingWebGLPolicy(bool forced)
-{
- m_forcePendingWebGLPolicy = forced;
-}
-
void Settings::setPluginsEnabled(bool arePluginsEnabled)
{
if (m_arePluginsEnabled == arePluginsEnabled)
@@ -392,13 +358,6 @@
m_page->userStyleSheetLocationChanged();
}
-// FIXME: This quirk is needed because of Radar 4674537 and 5211271. We need to phase it out once Adobe
-// can fix the bug from their end.
-void Settings::setNeedsAdobeFrameReloadingQuirk(bool shouldNotReloadIFramesForUnchangedSRC)
-{
- m_needsAdobeFrameReloadingQuirk = shouldNotReloadIFramesForUnchangedSRC;
-}
-
void Settings::setMinimumDOMTimerInterval(Seconds interval)
{
auto oldTimerInterval = std::exchange(m_minimumDOMTimerInterval, interval);
@@ -433,20 +392,6 @@
PageCache::singleton().pruneToSizeNow(0, PruningReason::None);
}
-void Settings::setFontRenderingMode(FontRenderingMode mode)
-{
- if (fontRenderingMode() == mode)
- return;
- m_fontRenderingMode = static_cast<int>(mode);
- if (m_page)
- m_page->setNeedsRecalcStyleInAllFrames();
-}
-
-FontRenderingMode Settings::fontRenderingMode() const
-{
- return static_cast<FontRenderingMode>(m_fontRenderingMode);
-}
-
void Settings::setDNSPrefetchingEnabled(bool dnsPrefetchingEnabled)
{
if (m_dnsPrefetchingEnabled == dnsPrefetchingEnabled)
@@ -457,14 +402,6 @@
m_page->dnsPrefetchingStateChanged();
}
-void Settings::setShowTiledScrollingIndicator(bool enabled)
-{
- if (m_showTiledScrollingIndicator == enabled)
- return;
-
- m_showTiledScrollingIndicator = enabled;
-}
-
#if ENABLE(RESOURCE_USAGE)
void Settings::setResourceUsageOverlayVisible(bool visible)
{
@@ -650,24 +587,6 @@
m_page->hiddenPageCSSAnimationSuspensionStateChanged();
}
-void Settings::setFontFallbackPrefersPictographs(bool preferPictographs)
-{
- if (m_fontFallbackPrefersPictographs == preferPictographs)
- return;
-
- m_fontFallbackPrefersPictographs = preferPictographs;
- if (m_page)
- m_page->setNeedsRecalcStyleInAllFrames();
-}
-
-void Settings::setWebFontsAlwaysFallBack(bool enable)
-{
- if (m_webFontsAlwaysFallBack == enable)
- return;
-
- m_webFontsAlwaysFallBack = enable;
-}
-
void Settings::setLowPowerVideoAudioBufferSizeEnabled(bool flag)
{
gLowPowerVideoAudioBufferSizeEnabled = flag;
Modified: trunk/Source/WebCore/page/Settings.h (222697 => 222698)
--- trunk/Source/WebCore/page/Settings.h 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/page/Settings.h 2017-10-02 06:02:52 UTC (rev 222698)
@@ -30,7 +30,6 @@
#include "SecurityOrigin.h"
#include "SettingsDefaultValues.h"
#include "SettingsGenerated.h"
-#include "TextFlags.h"
#include "Timer.h"
#include "URL.h"
#include <unicode/uscript.h>
@@ -88,19 +87,9 @@
bool isScriptEnabled() const { return m_isScriptEnabled; }
WEBCORE_EXPORT void setScriptEnabled(bool);
- WEBCORE_EXPORT void setJavaEnabled(bool);
- bool isJavaEnabled() const { return m_isJavaEnabled; }
-
- // This settings is only consulted if isJavaEnabled() returns true;
- WEBCORE_EXPORT void setJavaEnabledForLocalFiles(bool);
- bool isJavaEnabledForLocalFiles() const { return m_isJavaEnabledForLocalFiles; }
-
WEBCORE_EXPORT void setImagesEnabled(bool);
bool areImagesEnabled() const { return m_areImagesEnabled; }
- WEBCORE_EXPORT void setPreferMIMETypeForImages(bool);
- bool preferMIMETypeForImages() const { return m_preferMIMETypeForImages; }
-
WEBCORE_EXPORT void setPluginsEnabled(bool);
bool arePluginsEnabled() const { return m_arePluginsEnabled; }
@@ -110,9 +99,6 @@
WEBCORE_EXPORT void setUserStyleSheetLocation(const URL&);
const URL& userStyleSheetLocation() const { return m_userStyleSheetLocation; }
- WEBCORE_EXPORT void setNeedsAdobeFrameReloadingQuirk(bool);
- bool needsAcrobatFrameReloadingQuirk() const { return m_needsAdobeFrameReloadingQuirk; }
-
WEBCORE_EXPORT void setMinimumDOMTimerInterval(Seconds); // Initialized to DOMTimer::defaultMinimumInterval().
Seconds minimumDOMTimerInterval() const { return m_minimumDOMTimerInterval; }
@@ -126,13 +112,7 @@
WEBCORE_EXPORT void setUsesPageCache(bool);
bool usesPageCache() const { return m_usesPageCache; }
-
- void setFontRenderingMode(FontRenderingMode mode);
- FontRenderingMode fontRenderingMode() const;
- WEBCORE_EXPORT void setShowTiledScrollingIndicator(bool);
- bool showTiledScrollingIndicator() const { return m_showTiledScrollingIndicator; }
-
#if ENABLE(RESOURCE_USAGE)
bool resourceUsageOverlayVisible() const { return m_resourceUsageOverlayVisible; }
WEBCORE_EXPORT void setResourceUsageOverlayVisible(bool);
@@ -183,11 +163,6 @@
WEBCORE_EXPORT static void setUsesMockScrollAnimator(bool);
static bool usesMockScrollAnimator();
-#if ENABLE(TOUCH_EVENTS)
- void setTouchEventEmulationEnabled(bool enabled) { m_touchEventEmulationEnabled = enabled; }
- bool isTouchEventEmulationEnabled() const { return m_touchEventEmulationEnabled; }
-#endif
-
WEBCORE_EXPORT void setStorageBlockingPolicy(SecurityOrigin::StorageBlockingPolicy);
SecurityOrigin::StorageBlockingPolicy storageBlockingPolicy() const { return m_storageBlockingPolicy; }
@@ -197,18 +172,9 @@
WEBCORE_EXPORT static void setShouldRespectPriorityInCSSAttributeSetters(bool);
static bool shouldRespectPriorityInCSSAttributeSetters();
- void setTimeWithoutMouseMovementBeforeHidingControls(Seconds time) { m_timeWithoutMouseMovementBeforeHidingControls = time; }
- Seconds timeWithoutMouseMovementBeforeHidingControls() const { return m_timeWithoutMouseMovementBeforeHidingControls; }
-
bool hiddenPageCSSAnimationSuspensionEnabled() const { return m_hiddenPageCSSAnimationSuspensionEnabled; }
WEBCORE_EXPORT void setHiddenPageCSSAnimationSuspensionEnabled(bool);
- WEBCORE_EXPORT void setFontFallbackPrefersPictographs(bool);
- bool fontFallbackPrefersPictographs() const { return m_fontFallbackPrefersPictographs; }
-
- WEBCORE_EXPORT void setWebFontsAlwaysFallBack(bool);
- bool webFontsAlwaysFallBack() const { return m_webFontsAlwaysFallBack; }
-
static bool lowPowerVideoAudioBufferSizeEnabled() { return gLowPowerVideoAudioBufferSizeEnabled; }
WEBCORE_EXPORT static void setLowPowerVideoAudioBufferSizeEnabled(bool);
@@ -241,16 +207,8 @@
static void setCustomPasteboardDataEnabled(bool enabled) { gCustomPasteboardDataEnabled = enabled; }
WEBCORE_EXPORT static bool customPasteboardDataEnabled();
-
-#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
- void setMediaKeysStorageDirectory(const String& directory) { m_mediaKeysStorageDirectory = directory; }
- const String& mediaKeysStorageDirectory() const { return m_mediaKeysStorageDirectory; }
-#endif
#if ENABLE(MEDIA_STREAM)
- void setMediaDeviceIdentifierStorageDirectory(const String& directory) { m_mediaDeviceIdentifierStorageDirectory = directory; }
- const String& mediaDeviceIdentifierStorageDirectory() const { return m_mediaDeviceIdentifierStorageDirectory; }
-
static bool mockCaptureDevicesEnabled();
WEBCORE_EXPORT static void setMockCaptureDevicesEnabled(bool);
@@ -258,17 +216,6 @@
WEBCORE_EXPORT static void setMediaCaptureRequiresSecureConnection(bool);
#endif
-#if ENABLE(APPLE_PAY)
- bool applePayEnabled() const { return m_applePayEnabled; }
- void setApplePayEnabled(bool applePayEnabled) { m_applePayEnabled = applePayEnabled; }
-
- bool applePayCapabilityDisclosureAllowed() const { return m_applePayCapabilityDisclosureAllowed; }
- void setApplePayCapabilityDisclosureAllowed(bool applePayCapabilityDisclosureAllowed) { m_applePayCapabilityDisclosureAllowed = applePayCapabilityDisclosureAllowed; }
-#endif
-
- WEBCORE_EXPORT void setForcePendingWebGLPolicy(bool);
- bool isForcePendingWebGLPolicy() const { return m_forcePendingWebGLPolicy; }
-
WEBCORE_EXPORT static void setAllowsAnySSLCertificate(bool);
static bool allowsAnySSLCertificate();
@@ -289,37 +236,22 @@
Seconds m_layoutInterval;
Seconds m_minimumDOMTimerInterval;
- bool m_isJavaEnabled : 1;
- bool m_isJavaEnabledForLocalFiles : 1;
bool m_loadsImagesAutomatically : 1;
bool m_areImagesEnabled : 1;
- bool m_preferMIMETypeForImages : 1;
bool m_arePluginsEnabled : 1;
bool m_isScriptEnabled : 1;
- bool m_needsAdobeFrameReloadingQuirk : 1;
bool m_usesPageCache : 1;
- unsigned m_fontRenderingMode : 1;
- bool m_showTiledScrollingIndicator : 1;
bool m_backgroundShouldExtendBeyondPage : 1;
bool m_dnsPrefetchingEnabled : 1;
-#if ENABLE(TOUCH_EVENTS)
- bool m_touchEventEmulationEnabled : 1;
-#endif
bool m_scrollingPerformanceLoggingEnabled : 1;
- Seconds m_timeWithoutMouseMovementBeforeHidingControls;
-
Timer m_setImageLoadingSettingsTimer;
void imageLoadingSettingsTimerFired();
bool m_hiddenPageDOMTimerThrottlingEnabled : 1;
bool m_hiddenPageCSSAnimationSuspensionEnabled : 1;
- bool m_fontFallbackPrefersPictographs : 1;
- bool m_webFontsAlwaysFallBack : 1;
- bool m_forcePendingWebGLPolicy : 1;
-
#if ENABLE(RESOURCE_USAGE)
bool m_resourceUsageOverlayVisible { false };
#endif
@@ -355,21 +287,11 @@
WEBCORE_EXPORT static bool gManageAudioSession;
WEBCORE_EXPORT static bool gCustomPasteboardDataEnabled;
-#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
- String m_mediaKeysStorageDirectory;
-#endif
-
#if ENABLE(MEDIA_STREAM)
- String m_mediaDeviceIdentifierStorageDirectory;
static bool gMockCaptureDevicesEnabled;
static bool gMediaCaptureRequiresSecureConnection;
#endif
-#if ENABLE(APPLE_PAY)
- bool m_applePayEnabled { false };
- bool m_applePayCapabilityDisclosureAllowed { true };
-#endif
-
static bool gLowPowerVideoAudioBufferSizeEnabled;
static bool gResourceLoadStatisticsEnabledEnabled;
static bool gAllowsAnySSLCertificate;
Modified: trunk/Source/WebCore/page/Settings.in (222697 => 222698)
--- trunk/Source/WebCore/page/Settings.in 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/page/Settings.in 2017-10-02 06:02:52 UTC (rev 222698)
@@ -66,6 +66,7 @@
showDebugBorders initial=false, setNeedsStyleRecalcInAllFrames=1
showRepaintCounter initial=false, setNeedsStyleRecalcInAllFrames=1
visibleDebugOverlayRegions type=DebugOverlayRegions, initial=0
+showTiledScrollingIndicator initial=false
# This is a quirk we are pro-actively applying to old applications. It changes keyboard event dispatching,
# making keyIdentifier available on keypress events, making charCode available on keydown/keyup events,
@@ -301,7 +302,32 @@
allowMediaContentTypesRequiringHardwareSupportAsFallback initial=false
+storageAccessAPIEnabled initial=false
+
+timeWithoutMouseMovementBeforeHidingControls type=Seconds, initial=3_s
+
+fontFallbackPrefersPictographs initial=false, setNeedsStyleRecalcInAllFrames=1
+webFontsAlwaysFallBack initial=false
+
paymentRequestEnabled initial=false, conditional=PAYMENT_REQUEST
-storageAccessAPIEnabled initial=false
+applePayEnabled initial=false, conditional=APPLE_PAY
+applePayCapabilityDisclosureAllowed initial=true, conditional=APPLE_PAY
+javaEnabled initial=false, getter=isJavaEnabled
+javaEnabledForLocalFiles initial=true, getter=isJavaEnabledForLocalFiles
+
+fontRenderingMode type=FontRenderingMode, initial=FontRenderingMode::Normal
+
+preferMIMETypeForImages initial=false
+
+forcePendingWebGLPolicy initial=false, getter=isForcePendingWebGLPolicy
+
+mediaKeysStorageDirectory type=String, conditional=LEGACY_ENCRYPTED_MEDIA
+mediaDeviceIdentifierStorageDirectory type=String, conditional=MEDIA_STREAM
+
+# FIXME: This quirk is needed because of Radar 4674537 and 5211271. We need to phase it out once Adobe
+# can fix the bug from their end.
+needsAdobeFrameReloadingQuirk initial=false, getter=needsAcrobatFrameReloadingQuirk
+
+touchEventEmulationEnabled initial=false, getter=isTouchEventEmulationEnabled, conditional=TOUCH_EVENTS
\ No newline at end of file
Added: trunk/Source/WebCore/platform/text/FontRenderingMode.h (0 => 222698)
--- trunk/Source/WebCore/platform/text/FontRenderingMode.h (rev 0)
+++ trunk/Source/WebCore/platform/text/FontRenderingMode.h 2017-10-02 06:02:52 UTC (rev 222698)
@@ -0,0 +1,34 @@
+/*
+ * Copyright (C) 2003, 2006 Apple Inc. All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ * notice, this list of conditions and the following disclaimer in the
+ * documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#pragma once
+
+namespace WebCore {
+
+// This setting is used to provide ways of switching between multiple rendering modes that may have different
+// metrics. It is used to switch between CG and GDI text on Windows.
+enum class FontRenderingMode { Normal, Alternate };
+
+}
Modified: trunk/Source/WebCore/platform/text/TextFlags.h (222697 => 222698)
--- trunk/Source/WebCore/platform/text/TextFlags.h 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/platform/text/TextFlags.h 2017-10-02 06:02:52 UTC (rev 222698)
@@ -25,6 +25,8 @@
#pragma once
+#include "FontRenderingMode.h"
+
namespace WebCore {
enum TextRenderingMode { AutoTextRendering, OptimizeSpeed, OptimizeLegibility, GeometricPrecision };
@@ -31,10 +33,6 @@
enum FontSmoothingMode { AutoSmoothing, NoSmoothing, Antialiased, SubpixelAntialiased };
-// This setting is used to provide ways of switching between multiple rendering modes that may have different
-// metrics. It is used to switch between CG and GDI text on Windows.
-enum class FontRenderingMode { Normal, Alternate };
-
enum FontOrientation { Horizontal, Vertical };
enum class NonCJKGlyphOrientation { Mixed, Upright };
--- trunk/Source/WebCore/Scripts/GenerateSettings/Settings.py 2017-10-02 04:46:32 UTC (rev 222697)
+++ trunk/Source/WebCore/Scripts/GenerateSettings/Settings.py 2017-10-02 06:02:52 UTC (rev 222698)
@@ -66,6 +66,7 @@
self.conditional = None
self.setNeedsStyleRecalcInAllFrames = None
self.include = None
+ self.getter = None
def __str__(self):
result = self.name + " TYPE:" + self.type
@@ -77,6 +78,8 @@
result += " RECALC:" + self.setNeedsStyleRecalcInAllFrames
if (self.include):
result += " INCLUDE:" + self.include
+ if (self.getter):
+ result += " GETTER:" + self.getter
return result
@@ -91,6 +94,12 @@
return "set" + uppercaseFirstN(setting.name, 1)
+def makeGetterFunctionName(setting):
+ if setting.getter:
+ return setting.getter
+ return setting.name
+
+
def makePreferredConditional(conditional):
return conditional.split('|')[0]
@@ -131,15 +140,10 @@
return False
-def typeIsAggregate(setting):
- # Special case supported aggregates (e.g. classes/structs)
+def typeIsValueType(setting):
if setting.type == 'String':
return True
- if setting.type == 'IntSize':
- return True
- # Everything else is an enum
- # FIXME: Should we make it a requirement to annotate enums or classes/structs in someway?
return False
@@ -152,10 +156,12 @@
if typeIsPrimitive(setting):
return None
# Special case String, as it doesn't follow the pattern of being in a file with the
# same name as the class.
if setting.type == 'String':
return "<wtf/text/WTFString.h>"
+ if setting.type == 'Seconds':
+ return "<wtf/Seconds.h>"
# Default to using the type name for the include.
return "\"" + setting.type + ".h\""
@@ -182,6 +188,8 @@
setting.setNeedsStyleRecalcInAllFrames = value
if (name == 'include'):
setting.include = value
+ if (name == 'getter'):
+ setting.getter = value
# FIXME: ASSERT something about setting.initial
Modified: trunk/Source/WebCore/WebCore.xcodeproj/project.pbxproj (222697 => 222698)
@@ -152,10 +156,12 @@
if typeIsPrimitive(setting):
return None
- # Special case String, as it doesn't follow the pattern of being in a file with the
+ # Special case String and Seconds, as they doesn't follow the pattern of being in a file with the
# same name as the class.
if setting.type == 'String':